@@ -25,7 +25,7 @@ from . import aes, text, util
 
 
 SUPPORTED_BROWSERS_CHROMIUM = {
-    "brave", "chrome", "chromium", "edge", "opera", "vivaldi"}
+    "brave", "chrome", "chromium", "edge", "opera", "thorium", "vivaldi"}
 SUPPORTED_BROWSERS = SUPPORTED_BROWSERS_CHROMIUM | {"firefox", "safari"}
 
 logger = logging.getLogger("cookies")
@@ -354,6 +354,7 @@ def _get_chromium_based_browser_settings(browser_name):
             "chromium": join(appdata_local, R"Chromium\User Data"),
             "edge"    : join(appdata_local, R"Microsoft\Edge\User Data"),
             "opera"   : join(appdata_roaming, R"Opera Software\Opera Stable"),
+            "thorium" : join(appdata_local, R"Thorium\User Data"),
             "vivaldi" : join(appdata_local, R"Vivaldi\User Data"),
         }[browser_name]
 
@@ -365,6 +366,7 @@ def _get_chromium_based_browser_settings(browser_name):
             "chromium": join(appdata, "Chromium"),
             "edge"    : join(appdata, "Microsoft Edge"),
             "opera"   : join(appdata, "com.operasoftware.Opera"),
+            "thorium" : join(appdata, "Thorium"),
             "vivaldi" : join(appdata, "Vivaldi"),
         }[browser_name]
 
@@ -377,6 +379,7 @@ def _get_chromium_based_browser_settings(browser_name):
             "chromium": join(config, "chromium"),
             "edge"    : join(config, "microsoft-edge"),
             "opera"   : join(config, "opera"),
+            "thorium" : join(config, "Thorium"),
             "vivaldi" : join(config, "vivaldi"),
         }[browser_name]
 
@@ -390,6 +393,7 @@ def _get_chromium_based_browser_settings(browser_name):
         "edge"    : "Microsoft Edge" if sys.platform == "darwin" else
                     "Chromium",
         "opera"   : "Opera" if sys.platform == "darwin" else "Chromium",
+        "thorium" : "Thorium",
         "vivaldi" : "Vivaldi" if sys.platform == "darwin" else "Chrome",
     }[browser_name]
 
