@@ -293,9 +293,14 @@ def build_parser():
     )
     output.add_argument(
         "-j", "--dump-json",
-        dest="jobtype", action="store_const", const=job.DataJob,
+        dest="dump_json", action="count",
         help="Print JSON information",
     )
+    output.add_argument(
+        "-J", "--resolve-json",
+        dest="dump_json", action="store_const", const=128,
+        help="Print JSON information; resolve intermediary URLs",
+    )
     output.add_argument(
         "-s", "--simulate",
         dest="jobtype", action="store_const", const=job.SimulationJob,
@@ -345,6 +350,11 @@ def build_parser():
         help=("Write downloaded intermediary pages to files "
               "in the current directory to debug problems"),
     )
+    output.add_argument(
+        "--print-traffic",
+        dest="print_traffic", action="store_true",
+        help=("Display sent and read HTTP traffic"),
+    )
     output.add_argument(
         "--no-colors",
         dest="colors", action="store_false",
